@@ -362,6 +362,8 @@ class MetroFirefoxProfile(Profile):
                    'browser.shell.checkDefaultBrowser' : False,
                    # Don't send Firefox health reports to the production server
                    'datareporting.healthreport.documentServerURI' : 'http://%(server)s/healthreport/',
+                   # Enable extensions
+                   'extensions.defaultProviders.enabled' : True,
                    # Only install add-ons from the profile and the application scope
                    # Also ensure that those are not getting disabled.
                    # see: https://developer.mozilla.org/en/Installing_extensions
